Method: Mutx::Tasks::Task#command

Defined in:
lib/mutx/tasks/task.rb

#commandObject

Task means what a user can Run. It coul be a test or a tests suites according to the test organization and the used framework There are two types of task: A task properly said and a test. A platform can be specified. It could be one of following:

"bash" => Aimed to run bash commands
"ruby" => When you want to run ruby code
"java" => Well, if you wanto to do it, poor you :P


14
15
16
# File 'lib/mutx/tasks/task.rb', line 14

def command
  @command
end